package javax.swing.plaf.basic;

import java.io.ByteArrayInputStream;
import sun.awt.datatransfer.DataTransferer;
import java.io.IOException;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.StringReader;
import java.io.InputStream;
import java.io.Reader;
import java.awt.datatransfer.DataFlavor;
import javax.swing.plaf.UIResource;
import java.awt.datatransfer.Transferable;

class BasicTransferable implements Transferable, UIResource
{
    protected String plainData;
    protected String htmlData;
    private static DataFlavor[] htmlFlavors;
    private static DataFlavor[] stringFlavors;
    private static DataFlavor[] plainFlavors;
    
    public BasicTransferable(String plainData, String htmlData) {
        this.plainData = plainData;
        this.htmlData = htmlData;
    }
    
    @Override
    public DataFlavor[] getTransferDataFlavors() {
        DataFlavor[] richerFlavors = this.getRicherFlavors();
        int n = (richerFlavors != null) ? richerFlavors.length : 0;
        int n2 = this.isHTMLSupported() ? BasicTransferable.htmlFlavors.length : 0;
        int n3 = this.isPlainSupported() ? BasicTransferable.plainFlavors.length : 0;
        int n4 = this.isPlainSupported() ? BasicTransferable.stringFlavors.length : 0;
        DataFlavor[] array = new DataFlavor[n + n2 + n3 + n4];
        int n5 = 0;
        if (n > 0) {
            System.arraycopy(richerFlavors, 0, array, n5, n);
            n5 += n;
        }
        if (n2 > 0) {
            System.arraycopy(BasicTransferable.htmlFlavors, 0, array, n5, n2);
            n5 += n2;
        }
        if (n3 > 0) {
            System.arraycopy(BasicTransferable.plainFlavors, 0, array, n5, n3);
            n5 += n3;
        }
        if (n4 > 0) {
            System.arraycopy(BasicTransferable.stringFlavors, 0, array, n5, n4);
            return array;
        }
        return array;
    }
    
    @Override
    public boolean isDataFlavorSupported(DataFlavor that) {
        DataFlavor[] transferDataFlavors = this.getTransferDataFlavors();
        int i = 0;
        while (i < transferDataFlavors.length) {
            if (transferDataFlavors[i].equals(that)) {
                return true;
            }
            ++i;
        }
        return false;
    }
    
    @Override
    public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException, IOException {
        this.getRicherFlavors();
        if (this.isRicherFlavor(flavor)) {
            return this.getRicherData(flavor);
        }
        if (this.isHTMLFlavor(flavor)) {
            String htmlData = this.getHTMLData();
            String s2 = (htmlData == null) ? "" : htmlData;
            if (String.class.equals(flavor.getRepresentationClass())) {
                return s2;
            }
            if (Reader.class.equals(flavor.getRepresentationClass())) {
                return new StringReader(s2);
            }
            if (InputStream.class.equals(flavor.getRepresentationClass())) {
                return this.createInputStream(flavor, s2);
            }
        }
        else if (this.isPlainFlavor(flavor)) {
            String plainData2 = this.getPlainData();
            String s = (plainData2 == null) ? "" : plainData2;
            if (String.class.equals(flavor.getRepresentationClass())) {
                return s;
            }
            if (Reader.class.equals(flavor.getRepresentationClass())) {
                return new StringReader(s);
            }
            if (InputStream.class.equals(flavor.getRepresentationClass())) {
                return this.createInputStream(flavor, s);
            }
        }
        else if (this.isStringFlavor(flavor)) {
            String plainData = this.getPlainData();
            return (plainData == null) ? "" : plainData;
        }
        throw new UnsupportedFlavorException(flavor);
    }
    
    private InputStream createInputStream(DataFlavor flavor, String s) throws IOException, UnsupportedFlavorException {
        String textCharset = DataTransferer.getTextCharset(flavor);
        if (textCharset == null) {
            throw new UnsupportedFlavorException(flavor);
        }
        return new ByteArrayInputStream(s.getBytes(textCharset));
    }
    
    protected boolean isRicherFlavor(DataFlavor that) {
        DataFlavor[] richerFlavors = this.getRicherFlavors();
        int n = (richerFlavors != null) ? richerFlavors.length : 0;
        int i = 0;
        while (i < n) {
            if (richerFlavors[i].equals(that)) {
                return true;
            }
            ++i;
        }
        return false;
    }
    
    protected DataFlavor[] getRicherFlavors() {
        return null;
    }
    
    protected Object getRicherData(DataFlavor dataFlavor) throws UnsupportedFlavorException {
        return null;
    }
    
    protected boolean isHTMLFlavor(DataFlavor that) {
        DataFlavor[] htmlFlavors = BasicTransferable.htmlFlavors;
        int i = 0;
        while (i < htmlFlavors.length) {
            if (htmlFlavors[i].equals(that)) {
                return true;
            }
            ++i;
        }
        return false;
    }
    
    protected boolean isHTMLSupported() {
        return this.htmlData != null;
    }
    
    protected String getHTMLData() {
        return this.htmlData;
    }
    
    protected boolean isPlainFlavor(DataFlavor that) {
        DataFlavor[] plainFlavors = BasicTransferable.plainFlavors;
        int i = 0;
        while (i < plainFlavors.length) {
            if (plainFlavors[i].equals(that)) {
                return true;
            }
            ++i;
        }
        return false;
    }
    
    protected boolean isPlainSupported() {
        return this.plainData != null;
    }
    
    protected String getPlainData() {
        return this.plainData;
    }
    
    protected boolean isStringFlavor(DataFlavor that) {
        DataFlavor[] stringFlavors = BasicTransferable.stringFlavors;
        int i = 0;
        while (i < stringFlavors.length) {
            if (stringFlavors[i].equals(that)) {
                return true;
            }
            ++i;
        }
        return false;
    }
    
    static {
        try {
            (BasicTransferable.htmlFlavors = new DataFlavor[3])[0] = new DataFlavor("text/html;class=java.lang.String");
            BasicTransferable.htmlFlavors[1] = new DataFlavor("text/html;class=java.io.Reader");
            BasicTransferable.htmlFlavors[2] = new DataFlavor("text/html;charset=unicode;class=java.io.InputStream");
            (BasicTransferable.plainFlavors = new DataFlavor[3])[0] = new DataFlavor("text/plain;class=java.lang.String");
            BasicTransferable.plainFlavors[1] = new DataFlavor("text/plain;class=java.io.Reader");
            BasicTransferable.plainFlavors[2] = new DataFlavor("text/plain;charset=unicode;class=java.io.InputStream");
            (BasicTransferable.stringFlavors = new DataFlavor[2])[0] = new DataFlavor("application/x-java-jvm-local-objectref;class=java.lang.String");
            BasicTransferable.stringFlavors[1] = DataFlavor.stringFlavor;
        }
        catch (ClassNotFoundException ex) {
            System.err.println("error initializing javax.swing.plaf.basic.BasicTranserable");
        }
    }
}
